==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/IssuerBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IssuerBuilder extends IssuerFluentImpl<IssuerBuilder> implements VisitableBuilder<Issuer,IssuerBuilder>{
  public IssuerBuilder() {
    this(false);
  }
  public IssuerBuilder(Boolean validationEnabled) {
    this(new Issuer(), validationEnabled);
  }
  public IssuerBuilder(IssuerFluent<?> fluent) {
    this(fluent, false);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Issuer(), validationEnabled);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Issuer instance) {
    this(fluent, instance, false);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Issuer instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IssuerBuilder(Issuer instance) {
    this(instance,false);
  }
  public IssuerBuilder(Issuer instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  IssuerFluent<?> fluent;
  Boolean validationEnabled;
  public Issuer build() {
    Issuer buildable = new Issuer(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/IssuerBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IssuerBuilder extends IssuerFluent<IssuerBuilder> implements VisitableBuilder<Issuer,IssuerBuilder>{
  public IssuerBuilder() {
    this(false);
  }
  public IssuerBuilder(Boolean validationEnabled) {
    this(new Issuer(), validationEnabled);
  }
  public IssuerBuilder(IssuerFluent<?> fluent) {
    this(fluent, false);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Issuer(), validationEnabled);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Issuer instance) {
    this(fluent, instance, false);
  }
  public IssuerBuilder(IssuerFluent<?> fluent,Issuer instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Issuer());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IssuerBuilder(Issuer instance) {
    this(instance,false);
  }
  public IssuerBuilder(Issuer instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Issuer());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  IssuerFluent<?> fluent;
  Boolean validationEnabled;
  public Issuer build() {
    Issuer buildable = new Issuer(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    return buildable;
  }
  
}
